@@ -1,3 +1,4 @@
+/* $XFree86: xc/programs/Xserver/hw/xfree86/etc/scanpci.c,v 3.100 2008/03/26 18:57:50 tsi Exp $ */
 /*
  * Copyright 2000 by Egbert Eich
  * Copyright 1995 by Robin Cutshaw <robin@XFree86.Org>
@@ -23,7 +24,6 @@
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
  */
-/* $XFree86: xc/programs/Xserver/hw/xfree86/etc/scanpci.c,v 3.99 2007/05/30 15:50:40 tsi Exp $ */
 
 #include <X11/X.h>
 #include "os.h"
@@ -340,6 +340,8 @@ dump_config(pciConfigPtr pcr, int verbose)
     /* Print the rest */
     for (;  i < limit;  i += 4) {
 	CARD32 pcireg = pciReadLong(pcr->tag, i);
+	if ((pcireg == (CARD32)(-1L)) && (i == 256))
+	    break;
 	if (!(i & 15))
 	    printf("    0x%03x: ", i);
 	if (!(i & 7))
@@ -657,7 +659,7 @@ print_header_type_1(pciConfigPtr pcr)
 	       pcr->pci_br_rom & 0x1 ? "" : "not ");
     }
 
-    printf("  %sFAST_B2B %sSEC_BUS_RST %sM_ABRT %sVGA_EN %sISA_EN"
+    printf("  %sFAST_B2B %sSEC_BUS_RST %sM_ABRT %sVGA16 %sVGA_EN %sISA_EN"
 	   " %sSERR_EN %sPERR_EN\n",
 	   (pcr->pci_bridge_control & PCI_PCI_BRIDGE_FAST_B2B_EN) ?
 		"" : "NO_",
@@ -665,6 +667,8 @@ print_header_type_1(pciConfigPtr pcr)
 		"" : "NO_",
 	   (pcr->pci_bridge_control & PCI_PCI_BRIDGE_MASTER_ABORT_EN) ?
 		"" : "NO_",
+	   (pcr->pci_bridge_control & PCI_PCI_BRIDGE_VGA16_EN) ?
+		"" : "NO_",
 	   (pcr->pci_bridge_control & PCI_PCI_BRIDGE_VGA_EN) ?
 		"" : "NO_",
 	   (pcr->pci_bridge_control & PCI_PCI_BRIDGE_ISA_EN) ?
@@ -737,7 +741,7 @@ print_header_type_2(pciConfigPtr pcr)
 	}
     }
 
-    printf("  %s16BIT_INT %sSEC_BUS_RST %sM_ABRT %sVGA_EN %sISA_EN"
+    printf("  %s16BIT_INT %sSEC_BUS_RST %sM_ABRT %sVGA16 %sVGA_EN %sISA_EN"
 	   " %sSERR_EN %sPERR_EN %sPOST_WRITES\n",
 	   (pcr->pci_bridge_control & PCI_CB_BRIDGE_CTL_16BIT_INT) ?
 		"" : "NO_",
@@ -745,6 +749,8 @@ print_header_type_2(pciConfigPtr pcr)
 		"" : "NO_",
 	   (pcr->pci_bridge_control & PCI_PCI_BRIDGE_MASTER_ABORT_EN) ?
 		"" : "NO_",
+	   (pcr->pci_bridge_control & PCI_PCI_BRIDGE_VGA16_EN) ?
+		"" : "NO_",
 	   (pcr->pci_bridge_control & PCI_PCI_BRIDGE_VGA_EN) ?
 		"" : "NO_",
 	   (pcr->pci_bridge_control & PCI_PCI_BRIDGE_ISA_EN) ?
