@@ -24,7 +24,7 @@
  *
  */
 
-/* $XFree86: xc/programs/Xserver/hw/xfree86/input/eloinput/xf86EloInput.c,v 1.2 2005/01/21 18:07:12 tsi Exp $ */
+/* $XFree86: xc/programs/Xserver/hw/xfree86/input/eloinput/xf86EloInput.c,v 1.4 2006/03/16 16:50:28 dawes Exp $ */
 
 /*
  ******************************************************************************
@@ -72,17 +72,17 @@
 
 #else /* XFREE86_V4 */
 
-#include "Xos.h"
+#include <X11/Xos.h>
 #include <signal.h>
 #include <stdio.h>
 
 #define	 NEED_EVENTS
-#include "X.h"
-#include "Xproto.h"
+#include <X11/X.h>
+#include <X11/Xproto.h>
 #include "inputstr.h"
 #include "scrnintstr.h"
-#include "XI.h"
-#include "XIproto.h"
+#include <X11/extensions/XI.h>
+#include <X11/extensions/XIproto.h>
 
 #if defined(sun) && !defined(i386)
 #include <errno.h>
@@ -998,8 +998,10 @@ InputDriverRec ELOINPUT = {
 };
 
 #ifdef XFree86LOADER
+static MODULESETUPPROTO(Plug);
+
 static pointer
-Plug(pointer	module,
+Plug(ModuleDescPtr	module,
      pointer	options,
      int	*errmaj,
      int	*errmin)
@@ -1008,6 +1010,8 @@ Plug(pointer	module,
   return module;
 }
 
+static MODULETEARDOWNPROTO(Unplug);
+
 static void
 Unplug(pointer	p)
 {
